@@ -12,6 +12,7 @@ if not os.getenv("READ_THE_DOCS"):
     from cognite.seismic.protos.types_pb2 import CRS as CRSProto
     from cognite.seismic.protos.types_pb2 import GeoJson, Wkt
     from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import Identifier, OptionalMap
+    from cognite.seismic.protos.v1.seismic_service_datatypes_pb2 import VolumeDef as VolumeDefPB
     from cognite.seismic.protos.v1.seismic_service_messages_pb2 import (
         CreateSeismicRequest,
         DeleteSeismicRequest,
@@ -67,7 +68,7 @@ class SeismicAPI(API):
 
         request = CreateSeismicRequest(external_id=external_id, partition=identifier, seismic_store_id=seismic_store_id)
         if volumedef is not None:
-            request.volume_def.MergeFrom(VolumeDef(json=volumedef))
+            request.volume_def.MergeFrom(VolumeDefPB(json=volumedef))
         elif geometry is not None:
             request.geometry.MergeFrom(geometry.to_proto())
 
