@@ -180,7 +180,7 @@ class VolumeDef:
     def __init__(self, json_payload):
         self.json = json_payload
         self.parsed = json.loads(json_payload)
-        if self.parsed["version"] > 102:
+        if self.parsed["version"] >= 200:
             raise Exception(
                 f'The specified volumedef version {self.parsed["version"]} is not supported by this version of the Cognite SDK.'
             )
@@ -236,15 +236,33 @@ class VolumeDef:
                 yield value
 
     @staticmethod
-    def _get_method_size(method) -> int:
-        """Given a volumedef method, calculate the number of traces within it"""
+    def _get_method_size(method, minor_range: Optional[Tuple[int, int]] = None) -> int:
+        """Given a volumedef method, calculate the number of traces within it and minor_range"""
         c = 0
         if "list" in method:
-            c += len(method["list"])
+            if minor_range is None:
+                c += len(method["list"])
+            else:
+                for minor in method["list"]:
+                    if minor < minor_range[0] or minor > minor_range[1]:
+                        continue
+                    c += 1
         elif "range" in method:
-            range_ = method["range"]
+            start, stop = method["range"][0:2]
             step = VolumeDef._get_range_step(method)
-            c += (range_[1] - range_[0]) // step + 1
+            # Let's simplify to a positive range, shall we?
+            if start > stop:
+                start, stop = stop, start
+                step = -step
+            if minor_range is not None:
+                if start < minor_range[0]:
+                    # This computes the ceiling of (minor_range[0] - start) / step
+                    nsteps = (minor_range[0] - start + step - 1) // step
+                    start = start + step * nsteps
+                if stop > minor_range[1]:
+                    stop = minor_range[1]
+            if stop >= start:
+                c += (stop - start) // step + 1
         else:
             raise Exception(f"The specified method {method} was not recognized.")
 
@@ -268,28 +286,39 @@ class VolumeDef:
         else:
             raise Exception(f"The specified method {method} was not recognized.")
 
-    def count_line_traces(self) -> Mapping[int, int]:
-        """Count the number of traces by line.
+    def count_line_traces(
+        self, inline_range: Optional[Tuple[int, int]] = None, xline_range: Optional[Tuple[int, int]] = None
+    ) -> Mapping[int, int]:
+        """Count the number of traces by line, optionally restricted by ranges.
 
         Returns:
             Mapping[int, int]: A mapping of line number to trace count.
         """
-        if self.parsed["version"] > 101:
+        if self.parsed["version"] >= 200:
             raise Exception(
                 f'The specified volumedef version {self.parsed["version"]} is not supported by this version of the Cognite SDK.'
             )
         output = {}
+        if self.direction == Direction.INLINE:
+            major_range, minor_range = inline_range, xline_range
+        else:
+            major_range, minor_range = xline_range, inline_range
         for key, methods in self.parsed["lines"].items():
+            key = int(key)
+            if major_range and (key < major_range[0] or key > major_range[1]):
+                continue
             c = 0
             for method in methods:
-                c += VolumeDef._get_method_size(method)
-            output[int(key)] = c
+                c += VolumeDef._get_method_size(method, minor_range)
+            output[key] = c
         return output
 
-    def count_total_traces(self) -> int:
-        """Count the total number of traces in this volumedef."""
+    def count_total_traces(
+        self, inline_range: Optional[Tuple[int, int]] = None, xline_range: Optional[Tuple[int, int]] = None
+    ) -> int:
+        """Count the total number of traces in this volumedef, optionally restricted by ranges."""
         c = 0
-        traces = self.count_line_traces()
+        traces = self.count_line_traces(inline_range, xline_range)
         for val in traces.values():
             c += val
         return c
@@ -360,6 +389,9 @@ class VolumeDef:
         min_major = min(majors)
         max_major = max(majors)
         step = max_major - min_major
+        if step == 0:
+            # A single major line only. Set step = 1 for simplicity.
+            return RangeInclusive(min_major, max_major, 1)
         for major in majors:
             if major < min_major or major > max_major:
                 continue
@@ -378,6 +410,9 @@ class VolumeDef:
         min_minor = min(r[0] for r in ranges)
         max_minor = max(r[1] for r in ranges)
         step = max_minor - min_minor
+        if step == 0:
+            # A single minor value. Set step = 1 for simplicity.
+            return RangeInclusive(min_minor, max_minor, 1)
         for methods in self.parsed["lines"].values():
             # Let's be stupid for now and just check all lines
             # This can be optimized by not iterating through the ranges
